==> verttice_ui-0.1.2.tar.gz: lib/src/widgets/themed_widgets/themed_rich_text_viewer.dart <==
// 🐦 Flutter imports:
import 'dart:convert';

import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

// 📦 Package imports:
import 'package:flutter_markdown/flutter_markdown.dart';
import 'package:flutter_quill/flutter_quill.dart';
import 'package:flutter_quill_extensions/flutter_quill_extensions.dart';
import 'package:html2md/html2md.dart' as html2md;
import 'package:validators/validators.dart';

// 🌎 Project imports:
import 'package:verttice_ui/verttice_ui.dart';

import 'themed_editor/editor_embed_builders_web/themed_editor_embed_builder_web.dart';

class ThemedRichTextViewer extends StatefulWidget {
  final String? markdown;
  final String? html;
  final String? delta;
  ThemedRichTextViewer({
    Key? key,
    this.html,
    this.markdown,
    this.delta,
  }) : super(key: key) {
    assert(
      html != null || markdown != null || delta != null,
      'Must provide html or markdown or delta',
    );
  }

  @override
  State<ThemedRichTextViewer> createState() => _ThemedRichTextViewerState();
}

class _ThemedRichTextViewerState extends State<ThemedRichTextViewer> {
  String? _markdown;

  @override
  void initState() {
    super.initState();
    if (widget.delta != null) {
      return;
    }
    if (widget.markdown != null) {
      _markdown = widget.markdown;
    } else {
      _iniMarkdown();
    }
  }

  _iniMarkdown() {
    final markdown = html2md.convert(widget.html!);

    setState(() {
      _markdown = markdown;
    });
  }

  @override
  Widget build(BuildContext context) {
    return _markdown == null
        ? centeredLoader
        : Padding(
            padding: const EdgeInsets.all(8.0),
            child: Builder(builder: (context) {
              if (widget.delta != null) {
                QuillEditor(
                  showCursor: false,
                  controller: QuillController(
                    document: Document.fromJson(
                      isJSON(widget.delta) ? json.decode(widget.delta!) : {},
                    ),
                    selection: const TextSelection.collapsed(offset: 0),
                  ),
                  scrollController: ScrollController(),
                  scrollable: false,
                  focusNode: FocusNode(),
                  autoFocus: false,
                  readOnly: true,
                  placeholder: null,
                  expands: false,
                  enableInteractiveSelection: false,
                  padding: const EdgeInsets.all(0),
                  embedBuilders: !kIsWeb
                      ? FlutterQuillEmbeds.builders()
                      : embedBuilderWeb(),
                );
              }
              return MarkdownBody(
                data: _markdown!,
                imageBuilder: (Uri url, String? _, String? __) {
                  return ImageViewer(
                    height: 275,
                    url: url.toString(),
                  );
                },
                selectable: true,
                onTapLink: (String text, String? href, String title) async {
                  if (await canLaunchUrl(Uri.parse(href ?? ""))) {
                    launchUrl(Uri.parse(href!));
                  }
                },
              );
            }),
          );
  }
}

==> verttice_ui-0.1.10.tar.gz: lib/src/widgets/themed_widgets/themed_rich_text_viewer.dart <==
// 🐦 Flutter imports:
import 'dart:convert';

import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

// 📦 Package imports:
import 'package:flutter_markdown/flutter_markdown.dart';
import 'package:flutter_quill/flutter_quill.dart';
import 'package:flutter_quill_extensions/flutter_quill_extensions.dart';
import 'package:html2md/html2md.dart' as html2md;
import 'package:validators/validators.dart';

// 🌎 Project imports:
import 'package:verttice_ui/verttice_ui.dart';

import 'themed_editor/editor_embed_builders_web/themed_editor_embed_builder_web.dart';

class ThemedRichTextViewer extends StatefulWidget {
  final String? markdown;
  final String? html;
  final String? delta;
  ThemedRichTextViewer({
    Key? key,
    this.html,
    this.markdown,
    this.delta,
  }) : super(key: key) {
    assert(
      html != null || markdown != null || delta != null,
      'Must provide html or markdown or delta',
    );
  }

  @override
  State<ThemedRichTextViewer> createState() => _ThemedRichTextViewerState();
}

class _ThemedRichTextViewerState extends State<ThemedRichTextViewer> {
  String? _markdown;

  @override
  void initState() {
    super.initState();
    if (widget.delta != null) {
      return;
    }
    if (widget.markdown != null) {
      _markdown = widget.markdown;
    } else {
      _iniMarkdown();
    }
  }

  _iniMarkdown() {
    final markdown = html2md.convert(widget.html!);

    setState(() {
      _markdown = markdown;
    });
  }

  @override
  Widget build(BuildContext context) {
    return _markdown == null
        ? centeredLoader
        : Padding(
            padding: const EdgeInsets.all(8.0),
            child: Builder(builder: (context) {
              if (widget.delta != null) {
                QuillEditor(
                  showCursor: false,
                  controller: QuillController(
                    document: Document.fromJson(
                      isJSON(widget.delta) ? json.decode(widget.delta!) : {},
                    ),
                    selection: const TextSelection.collapsed(offset: 0),
                  ),
                  scrollController: ScrollController(),
                  scrollable: false,
                  focusNode: FocusNode(),
                  autoFocus: false,
                  readOnly: true,
                  placeholder: null,
                  expands: false,
                  enableInteractiveSelection: false,
                  padding: const EdgeInsets.all(0),
                  embedBuilders: !kIsWeb
                      ? FlutterQuillEmbeds.builders()
                      : embedBuilderWeb(),
                );
              }
              return MarkdownBody(
                data: _markdown!,
                imageBuilder: (Uri url, String? _, String? __) {
                  return ImageViewer(
                    height: 275,
                    url: url.toString(),
                  );
                },
                selectable: true,
                onTapLink: (String text, String? href, String title) async {
                  if (await canLaunchUrl(Uri.parse(href ?? ""))) {
                    themedLaunchUrl(Uri.parse(href!));
                  }
                },
              );
            }),
          );
  }
}
